@@ -12,9 +12,10 @@
 #' @seealso
 #'   \code{\link[base]{attributes}}, specifically \code{mostattributes}
 #'
-#' @rdname extract
-#' @include sticky.R
+#' @rdname extract1
 #' @export
+#' @include sticky.R
+
 
 `[.sticky` <- function(x,...) {
 
@@ -23,7 +24,17 @@
   has_dim <- has_attr(r, 'dim')
   r_dim <- dim(r)
 
-  mostattributes(r) <- attributes(x)
+  #' When `[`` produces a different class, drop=TRUE
+  #' We should only copy attributes when the
+
+  cls_x <- setdiff( class(x), 'sticky' )
+  cls_r <- setdiff( class(r), 'sticky' )
+
+  if(
+    length( cls_x ) == length( cls_r ) &&
+    all( cls_x == cls_r )
+  )
+    mostattributes(r) <- attributes(x)
 
   if( has_dim ) dim(r) <- r_dim
 
